from deepranker import add, divide, multiply, subtract


def test_add() -> None:
    assert add(10, 5) == 15


def test_subtract() -> None:
    assert subtract(10, 5) == 5


def test_multiply() -> None:
    assert multiply(10, 5) == 50


def test_divide() -> None:
    assert divide(10, 5) == 2


def test_divide_by_zero_raises_value_error() -> None:
    try:
        divide(10, 0)
    except ValueError as exc:
        assert str(exc) == "Bir sayı sıfıra bölünemez."
    else:
        raise AssertionError("ValueError was not raised")



def add(a: float, b: float) :
    return a + b


def subtract(a: float, b: float) :
    return a - b


def multiply(a: float, b: float) :
    return a * b


def divide(a: float, b: float) :
    if b == 0:
        raise ValueError("Bir sayı sıfıra bölünemez.")
    return a / b


from src.FeatureRank.basic_operator import add, subtract, multiply, divide

print("Toplama:", add(10, 5))
print("Çıkarma:", subtract(10, 5))
print("Çarpma:", multiply(10, 5))
print("Bölme:", divide(10, 5))